@@ -7,7 +7,7 @@ package Dist::Zilla::PluginBundle::Author::KENTNL;
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
 
-our $VERSION = '2.021000';
+our $VERSION = '2.022000';
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
@@ -416,7 +416,7 @@ sub _configure_basic_tests {
   $self->add_plugin( 'PodSyntaxTests'         => {} );
   $self->add_plugin( 'Test::ReportPrereqs'    => {} );
   $self->add_plugin( 'Test::Kwalitee'         => {} );
-  $self->add_plugin( 'EOLTests'               => { trailing_whitespace => 1, } );
+  $self->add_plugin( 'Test::EOL'              => { trailing_whitespace => 1, } );
   $self->add_plugin( 'Test::MinimumVersion'   => {} );
   $self->add_plugin( 'Test::Compile::PerFile' => {} );
   $self->add_plugin( 'Test::Perl::Critic'     => {} );
@@ -673,7 +673,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 2.021000
+version 2.022000
 
 =head1 SYNOPSIS
 
